@@ -78,12 +78,12 @@ DAGS_COMMANDS = (
         # func=load_module_func("dagline.utils.commands.dag_command.dag_list_dags"),
         # args=(ARG_SUBDIR,),
     # ),
-    # ActionCommand(
-        # name="state",
-        # help="Get the status of a dag run",
-        # func=load_module_func("dagline.utils.commands.dag_command.dag_state"),
-        # args=(ARG_DAG_ID,),
-    # ),
+    ActionCommand(
+        name="show",
+        help="Visualize the DAG in html page",
+        func=load_module_func("dagline.utils.commands.dag_command.dag_show"),
+        args=(ARG_DAG_FILES_HOME, ARG_DAG_ID, ),
+    ),
     ActionCommand(
         name="run",
         help="Run a single DAG or run a single DAG from the specified tasks",
